﻿using System;
using System.Linq;
using System.Windows;
using Telerik.Windows.Controls.Diagrams;
using System.Windows.Input;
using Telerik.Windows.DragDrop;
using Telerik.Windows.Controls.Diagrams.Extensions;
using WpfApplication2.ViewModels;
using Telerik.Windows.Controls;

namespace WpfApplication2
{
    /// <summary>
    /// Interaction logic for MainWindow.xaml
    /// </summary>
    public partial class MainWindow : Window
    {
        private string diagramXMLString;
        public MainWindow()
        {
            InitializeComponent();
            //drag-drop handlers
            DragDropManager.AddDragInitializeHandler(toolbox, OnDragInitialize, true);
            DragDropManager.AddDropHandler(this.xDiagram, OnDiagramDrop);

            //creating custom connectors
            this.xDiagram.Shapes.ToList().ForEach(x =>
            {
                x.Connectors.Clear();
                var connectorRight1 = new RadDiagramConnector() { Offset = new Point(1, 0.25), Name = x.Name + "Connector1" };
                var connectorRight2 = new RadDiagramConnector() { Offset = new Point(1, 0.5), Name = x.Name + "Connector2" };
                var connectorRight3 = new RadDiagramConnector() { Offset = new Point(1, 0.75), Name = x.Name + "Connector3" };
                var connectorLeft1 = new RadDiagramConnector() { Offset = new Point(0, 0.25), Name = x.Name + "Connector4" };
                var connectorLeft2 = new RadDiagramConnector() { Offset = new Point(0, 0.5), Name = x.Name + "Connector5" };
                var connectorLeft3 = new RadDiagramConnector() { Offset = new Point(0, 0.75), Name = x.Name + "Connector6" };

                x.Connectors.Add(connectorRight1);
                x.Connectors.Add(connectorRight2);
                x.Connectors.Add(connectorRight3);
                x.Connectors.Add(connectorLeft1);
                x.Connectors.Add(connectorLeft2);
                x.Connectors.Add(connectorLeft3);
            });
        }
        private void OnDiagramDrop(object sender, Telerik.Windows.DragDrop.DragEventArgs e)
        {
            e.Handled = true;
            RadDiagram diagram = sender as RadDiagram;
            NodeViewModel droppedNode = (e.Data as DataObject).GetData(typeof(NodeViewModel)) as NodeViewModel;
            if (droppedNode != null)
            {
                droppedNode.Position = e.GetPosition(diagram);
                (diagram.GraphSource as GraphSource).AddNode(droppedNode);
            }
        }
        //Toolbox OnDragInitialize method implementation
        private void OnDragInitialize(object sender, DragInitializeEventArgs args)
        {
            args.AllowedEffects = DragDropEffects.All;
            RadDiagramToolboxItem draggedItem = args.OriginalSource as RadDiagramToolboxItem;
            if (draggedItem != null)
            {
                NodeViewModel node = draggedItem.Content as NodeViewModel;
                if (node != null)
                {
                    args.Data = node;
                }
            }
        }
        //save/load commands implementation
        private void CommandBinding_Executed_Save(object sender, ExecutedRoutedEventArgs e)
        {
            diagramXMLString = this.xDiagram.Save();
        }

        private void CommandBinding_Executed_Open(object sender, ExecutedRoutedEventArgs e)
        {
            if (diagramXMLString != null)
            {
                this.xDiagram.Load(diagramXMLString);
            }
        }

        private void CommandBinding_CanExecute(object sender, CanExecuteRoutedEventArgs e)
        {
            e.CanExecute = this.xDiagram.Items.Count > 0;
        }
    }

}
